==> tempest2-testing-docker-1.4.0-javadoc.jar: tempest-internal/app.cash.tempest.internal/index.md <==
[tempest-internal](../index.md) / [app.cash.tempest.internal](./index.md)

## Package app.cash.tempest.internal

### Types

| Name | Summary |
|---|---|
| [AttributeAnnotation](-attribute-annotation/index.md) | `interface AttributeAnnotation<T : `[`Annotation`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-annotation/index.html)`>` |
| [ClassFactory](-class-factory/index.md) | `abstract class ClassFactory<T>`<br>Magic that creates instances of arbitrary concrete classes. Derived from Gson's UnsafeAllocator and ConstructorConstructor classes. |
| [ClassMember](-class-member/index.md) | `data class ClassMember` |
| [Codec](-codec/index.md) | `interface Codec<A : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, D : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>`<br>Converts values between the mutable `DynamoDBMapper` objects that defines the union of all key and value attributes, and specific Tempest values. |
| [ForIndexAnnotation](-for-index-annotation/index.md) | `interface ForIndexAnnotation<T : `[`Annotation`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-annotation/index.html)`>` |
| [GetterMethodHandler](-getter-method-handler/index.md) | `class GetterMethodHandler : `[`MethodHandler`](-method-handler/index.md) |
| [ItemType](-item-type/index.md) | `data class ItemType : `[`LogicalType`](-logical-type/index.md) |
| [KeyType](-key-type/index.md) | `data class KeyType : `[`LogicalType`](-logical-type/index.md) |
| [LogicalType](-logical-type/index.md) | `sealed class LogicalType` |
| [MapAttributeValue](-map-attribute-value/index.md) | `interface MapAttributeValue<T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, DB : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>` |
| [MethodHandler](-method-handler/index.md) | `interface MethodHandler` |
| [ProxyFactory](-proxy-factory/index.md) | `class ProxyFactory` |
| [RawItemType](-raw-item-type/index.md) | `data class RawItemType : `[`LogicalType`](-logical-type/index.md) |
| [Schema](-schema/index.md) | `class Schema` |
| [StringAttributeValue](-string-attribute-value/index.md) | `interface StringAttributeValue<T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>` |

### Extensions for External Classes

| Name | Summary |
|---|---|
| [kotlin.reflect.KClass](kotlin.reflect.-k-class/index.md) |  |

==> tempest2-testing-docker-1.5.1-javadoc.jar: tempest-internal/app.cash.tempest.internal/index.md <==
[tempest-internal](../index.md) / [app.cash.tempest.internal](./index.md)

## Package app.cash.tempest.internal

### Types

| Name | Summary |
|---|---|
| [AttributeAnnotation](-attribute-annotation/index.md) | `interface AttributeAnnotation<T : `[`Annotation`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-annotation/index.html)`>` |
| [ClassFactory](-class-factory/index.md) | `abstract class ClassFactory<T>`<br>Magic that creates instances of arbitrary concrete classes. Derived from Gson's UnsafeAllocator and ConstructorConstructor classes. |
| [ClassMember](-class-member/index.md) | `data class ClassMember` |
| [Codec](-codec/index.md) | `interface Codec<A : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, D : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>`<br>Converts values between the mutable `DynamoDBMapper` objects that defines the union of all key and value attributes, and specific Tempest values. |
| [ForIndexAnnotation](-for-index-annotation/index.md) | `interface ForIndexAnnotation<T : `[`Annotation`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-annotation/index.html)`>` |
| [GetterMethodHandler](-getter-method-handler/index.md) | `class GetterMethodHandler : `[`MethodHandler`](-method-handler/index.md) |
| [ItemType](-item-type/index.md) | `data class ItemType : `[`LogicalType`](-logical-type/index.md) |
| [KeyType](-key-type/index.md) | `data class KeyType : `[`LogicalType`](-logical-type/index.md) |
| [LogicalType](-logical-type/index.md) | `sealed class LogicalType` |
| [MapAttributeValue](-map-attribute-value/index.md) | `interface MapAttributeValue<T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, DB : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>` |
| [MethodHandler](-method-handler/index.md) | `interface MethodHandler` |
| [ProxyFactory](-proxy-factory/index.md) | `object ProxyFactory` |
| [RawItemType](-raw-item-type/index.md) | `data class RawItemType : `[`LogicalType`](-logical-type/index.md) |
| [Schema](-schema/index.md) | `class Schema` |
| [StringAttributeValue](-string-attribute-value/index.md) | `interface StringAttributeValue<T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>` |

### Extensions for External Classes

| Name | Summary |
|---|---|
| [kotlin.reflect.KClass](kotlin.reflect.-k-class/index.md) |  |
